.. image:: https://badge.fury.io/py/layeredconfig.png
   :target: http://badge.fury.io/py/layeredconfig

.. image:: https://travis-ci.org/staffanm/layeredconfig.png?branch=master
   :target: https://travis-ci.org/staffanm/layeredconfig

.. image:: https://ci.appveyor.com/api/projects/status/nnfqv9jhxh3afgn0/branch/master
   :target: https://ci.appveyor.com/project/staffanm/layeredconfig/branch/master

.. image:: https://coveralls.io/repos/staffanm/layeredconfig/badge.png?branch=master
   :target: https://coveralls.io/r/staffanm/layeredconfig

.. image:: https://landscape.io/github/staffanm/layeredconfig/master/landscape.png
   :target: https://landscape.io/github/staffanm/layeredconfig/master
   :alt: Code Health

.. image:: https://pypip.in/d/layeredconfig/badge.png
   :target: https://pypi.python.org/pypi/layeredconfig

*Full documentation: https://layeredconfig.readthedocs.org/*
